@@ -4,13 +4,15 @@ import logging
 
 def normalize_bridge_id(bridge_id: str):
     """Normalize a bridge identifier."""
+    bridge_id = bridge_id.lower()
+
     # zeroconf: properties['id'], field contains semicolons after each 2 char
     if len(bridge_id) == 17 and sum(True for c in "aa:bb:cc:dd:ee:ff"
                                     if c == ":"):
         return bridge_id.replace(':', '')
 
     # nupnp: contains 4 extra characters in the middle: "fffe"
-    if len(bridge_id) == 16 and "fffe" in bridge_id:
+    if len(bridge_id) == 16 and bridge_id[6:10] == "fffe":
         return bridge_id[0:6] + bridge_id[-6:]
 
     # SSDP/UPNP and Hue Bridge API contains right ID.
